==> kubernetes-model-admissionregistration-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/NonResourceRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NonResourceRuleBuilder extends io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule,io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleBuilder>{
  public NonResourceRuleBuilder() {
    this(false);
  }
  public NonResourceRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new NonResourceRule(), validationEnabled);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NonResourceRule(), validationEnabled);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance) {
    this(fluent, instance, false);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withNonResourceURLs(instance.getNonResourceURLs()); 
    fluent.withVerbs(instance.getVerbs()); 
    this.validationEnabled = validationEnabled; 
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance) {
    this(instance,false);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withNonResourceURLs(instance.getNonResourceURLs()); 
    this.withVerbs(instance.getVerbs()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule build() {
    NonResourceRule buildable = new NonResourceRule(fluent.getNonResourceURLs(),fluent.getVerbs());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NonResourceRuleBuilder that = (NonResourceRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/NonResourceRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NonResourceRuleBuilder extends io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule,io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleBuilder>{
  public NonResourceRuleBuilder() {
    this(false);
  }
  public NonResourceRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new NonResourceRule(), validationEnabled);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NonResourceRule(), validationEnabled);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance) {
    this(fluent, instance, false);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withNonResourceURLs(instance.getNonResourceURLs()); 
    fluent.withVerbs(instance.getVerbs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance) {
    this(instance,false);
  }
  public NonResourceRuleBuilder(io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withNonResourceURLs(instance.getNonResourceURLs()); 
    this.withVerbs(instance.getVerbs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1.NonResourceRule build() {
    NonResourceRule buildable = new NonResourceRule(fluent.getNonResourceURLs(),fluent.getVerbs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NonResourceRuleBuilder that = (NonResourceRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
